==> sagcad_0.9.6.orig.tar.gz: sagcad-0.9.6/src/LayerSet.h <==
/* ====================================================================
 * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
 * ====================================================================
 * 
 *    Project              : SagCAD
 *    Description          : CAD/CAM
 *    Source               : LayerSet.h
 * 
 *    ----------------------------------
 * 
 *    License              : GNU General Public License (GPL)
 *    Copyright            : (C) 1998-2003 by Yutaka Sagiya
 *    email                : kappa@a6s.highway.ne.jp
 *                         : yutaka@sagiya.com
 *    Begin                : 2003/03/18
 *    Last                 : 2003/03/18
 * ====================================================================
 */
#ifndef __LAYERSET_H__
#define __LAYERSET_H__

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */



/* -------------------------------------------------------
 * 1 :   (struct #define etc)
 * -------------------------------------------------------
 */

struct _LAYERSET_DLG
{
	gint value;
	gint layerNo;

	GtkWidget *entry;
	GtkWidget *Layer_widget[257];
	GtkWidget *parent;
	GtkWidget *dialog;
};
typedef struct _LAYERSET_DLG LAYERSET_DLG;



/* -------------------------------------------------------
 * 2 : ѿ (global)
 * -------------------------------------------------------
 */
#ifdef _LAYERSET_
#define   GLOBAL
/*  */
#define   GLOBAL_VAL(v)  = (v)
#else
#define   GLOBAL	extern
/* ʬ̵ */
#define   GLOBAL_VAL(v)  /* */
#endif




#undef  GLOBAL
#undef  GLOBAL_VAL
#undef _LAYERSET_



/* -------------------------------------------------------
 * 3 : ؿ (Function)
 * -------------------------------------------------------
 */

/* 쥤䡼 */
gint LayerSetDialog(LAYERSET_DLG *layerset_dlg);



#ifdef __cplusplus
}
#endif /* __cplusplus */
#endif /* __LAYERSET_H__ */
/* ====================================================================
 * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
 * ====================================================================
 *    Project              : SagCAD
 *    Source               : LayerSet.h
 * ====================================================================
 */

==> sagcad-0.9.11.tar.gz: sagcad-0.9.11/src/LayerSet.h <==
/* ====================================================================
 * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
 * ====================================================================
 * 
 *    Project              : SagCAD
 *    Description          : CAD/CAM
 *    Source               : LayerSet.h
 * 
 *    ----------------------------------
 * 
 *    License              : GNU General Public License (GPL)
 *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
 *    email                : kappa@a6s.highway.ne.jp
 *                         : yutaka@sagiya.com
 *    Begin                : 2003/03/18
 *    Last                 : 2007/10/26
 * ====================================================================
 */
#ifndef __LAYERSET_H__
#define __LAYERSET_H__

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */



/* -------------------------------------------------------
 * 1 : 前処理  (struct #define etc)
 * -------------------------------------------------------
 */
#define LAYER_AREA_WIDTH             33
#define LAYER_AREA_HEIGHT            22
#define SAMPLE_LAYER_AREA_WIDTH      22
#define SAMPLE_LAYER_AREA_HEIGHT     22







struct _LAYERSET_DLG
{
	gint value;
	gint layerNo;
	gint use_layer;
	GtkWidget *entry;
	GtkWidget *Layer_widget[257];
	GtkWidget *parent;
	GtkWidget *dialog;
};
typedef struct _LAYERSET_DLG LAYERSET_DLG;



/* -------------------------------------------------------
 * 2 : 外部変数 (global)
 * -------------------------------------------------------
 */
#ifdef _LAYERSET_
#define   GLOBAL
/* 初期値設定 */
#define   GLOBAL_VAL(v)  = (v)
#else
#define   GLOBAL	extern
/* 初期値設定の代入部分を無くす */
#define   GLOBAL_VAL(v)  /* */
#endif




#undef  GLOBAL
#undef  GLOBAL_VAL
#undef _LAYERSET_



/* -------------------------------------------------------
 * 3 : 外部関数 (Function)
 * -------------------------------------------------------
 */

/* レイヤー設定 */
gint LayerSetDialog(LAYERSET_DLG *layerset_dlg);



#ifdef __cplusplus
}
#endif /* __cplusplus */
#endif /* __LAYERSET_H__ */
/* ====================================================================
 * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
 * ====================================================================
 *    Project              : SagCAD
 *    Source               : LayerSet.h
 * ====================================================================
 */
